@@ -61,7 +61,6 @@ The one usage you should not care about is a loose signature when using
 
 import re
 
-
 __all__ = [
     'and_', 'or_', 'not_',
     'eq', 'neq',
@@ -77,6 +76,7 @@ __all__ = [
     'kwargs', 'KWARGS'
 ]
 
+
 class _ArgsSentinel(object):
     def __repr__(self):
         return '*args'
@@ -106,6 +106,13 @@ KWARGS = kwargs = {KWARGS_SENTINEL: '_'}
 
 # """
 
+
+class MatcherError(RuntimeError):
+    '''Indicates generic runtime error raised by mockito-python matchers
+    '''
+    pass
+
+
 class Matcher:
     def matches(self, arg):
         pass
@@ -246,18 +253,24 @@ class Matches(Matcher):
 class ArgumentCaptor(Matcher):
     def __init__(self, matcher=None):
         self.matcher = matcher or Any()
-        self.value = None
+        self.all_values = []
 
     def matches(self, arg):
         result = self.matcher.matches(arg)
         if not result:
             return
-        self.value = arg
+        self.all_values.append(arg)
         return True
 
+    @property
+    def value(self):
+        if not self.all_values:
+            raise MatcherError("No argument value was captured!")
+        return self.all_values[-1]
+
     def __repr__(self):
-        return "<ArgumentCaptor: matcher=%s value=%s>" % (
-            repr(self.matcher), self.value,
+        return "<ArgumentCaptor: matcher=%s values=%s>" % (
+            repr(self.matcher), self.all_values,
         )
 
 
@@ -370,14 +383,22 @@ def matches(regex, flags=0):
 
 
 def captor(matcher=None):
-    """Returns argument captor that captures value for further assertions
+    """Returns argument captor that captures values for further assertions
 
     Example::
 
-        arg_captor = captor(any(int))
-        when(mock).do_something(arg_captor)
+        arg = captor()
         mock.do_something(123)
-        assert arg_captor.value == 123
+        mock.do_something(456)
+        verify(mock).do_something(arg)
+        assert arg.value == 456
+        assert arg.all_values == [123, 456]
+
+    You can restrict what the captor captures using the other matchers
+    shown herein::
+
+        arg = captor(any(str))
+        arg = captor(contains("foo"))
 
     """
     return ArgumentCaptor(matcher)
